# Specify the name of the certificates to delete
$certificateName = "XPressEntryService"

# Find the certificates matching the given name
#only the original self-signed certs have the friendlyname XPressEntryService
$certificates = Get-ChildItem -Path Cert:\LocalMachine\My | Where-Object {$_.Subject -like "*$certificateName*" -and $_.FriendlyName -eq "XPressEntryService"}

$new_certificates = Get-ChildItem -Path Cert:\LocalMachine\My | Where-Object {$_.Subject -like "*$certificateName*" -and $_.FriendlyName -eq ""}

#if there are any old certificates, delete them, and then also regenerate a new one
If (($certificates -ne $null) -or (($certificates -eq $null) -and ($new_certificates -eq $null)))
{
    # Delete the old certificates
    $certificates | ForEach-Object {
        $thumbprint = $_.Thumbprint
        Write-Host "Deleting certificate with Thumbprint: $thumbprint"
        Remove-Item -Path "Cert:\LocalMachine\My\$thumbprint" -Confirm:$false
    }

    # Create a new self-signed certificate
    Write-Host "Creating a new certificate"
    $newcert = New-SelfSignedCertificate -DnsName "XPressEntryService" -NotAfter (Get-Date).AddYears(30)

    Write-Host "New Certificate Thumbprint: " + $newcert.Thumbprint

    Write-Host "Adding the urlacl for 30001"
    $outputProc0 = Start-Process cmd -ArgumentList "/c", "netsh http add urlacl url=https://+:30001/ user=Everyone" -NoNewWindow -PassThru -Wait

    #Clear any https bindings for the port
    Write-Host "Clearing the http ssl cert binding for 30001"
    $outputProc1 = Start-Process cmd -ArgumentList "/c", "netsh.exe http delete sslcert 0.0.0.0:30001" -NoNewWindow -PassThru -Wait
    Write-Host "Ran with code" $outputProc1.ExitCode

    #We are running a command to bind cert to port 30001 here
    $commandToRun = "netsh http add sslcert ipport=0.0.0.0:30001 certhash=" + $newcert.Thumbprint + " appid={1b5203fa-03cf-4461-ad47-89116541c671} certstorename=My"

    Write-Host "Running Command: " + $commandToRun
    $outputProc = Start-Process cmd -ArgumentList "/c", $commandToRun -NoNewWindow -PassThru -Wait


    Write-Host "Done with code" $outputProc.ExitCode
}
